@@ -107,6 +107,7 @@ public:
     void visitParameter(ParameterAst *node) override;
     void visitParameterList(ParameterListAst *node) override;
     void visitParameterType(ParameterTypeAst *node) override;
+    void visitParameterTypeHint(ParameterTypeHintAst *node) override;
     void visitPostprefixOperator(PostprefixOperatorAst *node) override;
     void visitPrintExpression(PrintExpressionAst *node) override;
     void visitPropertyType(PropertyTypeAst *node) override;
@@ -116,6 +117,7 @@ public:
     void visitReservedNonModifierIdentifier(ReservedNonModifierIdentifierAst *node) override;
     void visitReservedNonModifiers(ReservedNonModifiersAst *node) override;
     void visitReturnType(ReturnTypeAst *node) override;
+    void visitReturnTypeHint(ReturnTypeHintAst *node) override;
     void visitScalar(ScalarAst *node) override;
     void visitSemiReserved(SemiReservedAst *node) override;
     void visitSemiReservedIdentifier(SemiReservedIdentifierAst *node) override;
@@ -139,6 +141,9 @@ public:
     void visitTraitVisibilityModifiers(TraitVisibilityModifiersAst *node) override;
     void visitUnaryExpression(UnaryExpressionAst *node) override;
     void visitUnaryExpressionNotPlusminus(UnaryExpressionNotPlusminusAst *node) override;
+    void visitUnionParameterType(UnionParameterTypeAst *node) override;
+    void visitUnionPropertyType(UnionPropertyTypeAst *node) override;
+    void visitUnionReturnType(UnionReturnTypeAst *node) override;
     void visitUseNamespaceOrUseGroupedNamespace(UseNamespaceOrUseGroupedNamespaceAst *node) override;
     void visitUseStatement(UseStatementAst *node) override;
     void visitVarExpression(VarExpressionAst *node) override;
